@@ -11,7 +11,7 @@ use Log::Any::Adapter;
 #Default adapter
 Log::Any::Adapter->set('Stdout');
  
-our $VERSION    = '0.02';
+our $VERSION    = '0.03';
 
 my %LOG_LEVELS = (
                     '0'     => 'emergency',
@@ -102,11 +102,11 @@ __END__
 
 =head1 NAME
 
-Log::Any::Adapter::Multiplexor - Run any Log::Any:Adapter together
+B<Log::Any::Adapter::Multiplexor> - Run any Log::Any:Adapter together
 
 =head1 VERSION
 
- version 0.02
+ version 0.03
 
 =head1 SYNOPSIS
 
@@ -122,55 +122,65 @@ Log::Any::Adapter::Multiplexor - Run any Log::Any:Adapter together
                                                               'info'  => ['Log::Any::Adapter::Stdout'],
                                                             );
     #Log message to file log.txt
-    $log->info("Test info");
+    $log->error("Test error");
 
     #Log message to Stdout
-    $log->error("Test error");
+    $log->info("Test info");
 
     #You can override the behavior of log level
     #Example: Send warning log message to file warn_log.txt
     $multiplexor->set_logger('warning', 'Log::Any::Adapter::File', 'warn_log.txt');
     $log->warning('Warning message');
 
+    #Combine log level 'info' and 'debug'
+    $multiplexor->combine('info', 'debug');
+    $log->info($message); 
+    #Equals to:
+    $log->info($message);
+    $log->debug($message);
+
+
+
 =head1 DESCRIPTION
 
-    C<Log::Any::Adapter::Multiplexor> connects any Log::Any::Adapter to use together
+B<Log::Any::Adapter::Multiplexor> connects any Log::Any::Adapter to use together
 
 =head1 Functions
 
-    Specification function
+Specification function
 
 =head2 new
 
     my $multiplexor = Log::Any::Adapter::Multiplexor->new($log, %param);
 
     $log - $Log::Any::log object
-    %param
-        key     => Log level name
-        value   => Arrayref ['Adapter name', @params]
+%param
+key     => Log level name
+value   => Arrayref ['Adapter name', @params]
 
 =head2 set_logger
 
-    Set or override exists logger for Log::Any::Adapter::Multiplexor object
+Set or override exists logger for Log::Any::Adapter::Multiplexor object
 
     $multiplexor->set_logger($log_level, $adapter, @param);
-        $log_level  => Log levels (e.g. warning, info, error)
-        $adapter    => Log::Any::Adapter for this log level (etc 'Log::Any::Adapter::File)
-        @param      => Adapter params (e.g. filename)
+$log_level  => Log levels (e.g. warning, info, error)
+$adapter    => Log::Any::Adapter for this log level (etc 'Log::Any::Adapter::File)
+@param      => Adapter params (e.g. filename)
 
 =head2 combine
 
-    Duplicated logs from different log levels
+Duplicated logs from different log levels
 
     $multiplexor->combine('info', 'debug');
     $log->info($message);
-    equals to
+    #equals to
     $log->info($message);
     $log->debug($message);
 
 =head2 uncombine
 
-    Delete associations of log levels
+Delete associations of log levels
+    $multiplexor->uncombine();
 
 =head1 DEPENDENCE
 
@@ -182,16 +192,16 @@ L<Log::Any|Log::Any>, L<Log::Any::Adapter|Log::Any::Adapter>
 
 =item *
 
-    Pavel Andryushin <vrag867@gmail.com>
+Pavel Andryushin <vrag867@gmail.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-    This software is copyright (c) 2017 by Pavel Andryushin.
+This software is copyright (c) 2017 by Pavel Andryushin.
 
-    This is free software; you can redistribute it and/or modify it under
-    the same terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
